@@ -1,15 +1,16 @@
-use crate::data::scalar::{ScalarValue, ScalarValueHelpers};
-use crate::data::table::VegaFusionTable;
-use crate::error::Result;
-use crate::error::VegaFusionError;
 use crate::planning::stitch::CommPlan;
 use crate::proto::gen::tasks::{Variable, VariableNamespace};
 use crate::task_graph::graph::ScopedVariable;
 use crate::task_graph::task_value::TaskValue;
+use datafusion_common::ScalarValue;
 use itertools::Itertools;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::convert::TryFrom;
+use vegafusion_common::data::scalar::ScalarValueHelpers;
+use vegafusion_common::data::table::VegaFusionTable;
+
+use vegafusion_common::error::{Result, VegaFusionError};
 
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Serialize, Deserialize)]
 #[serde(rename_all = "lowercase")]
